## pydpd

### A DPD API wrapper (for UK only I believe)

Create DPD shipments and generate parcel labels from within your application or webapp.

You will need a valid DPD account and have API access enabled (which can be done by calling 0121 275 7336)

## Installation

Download and install can be done through PyPi

```
pip install pydpd
```
or

```python
git clone https://github.com/lewis-morris/pydpd
cd pydpd
pip install -e .
```

## Usage

I always find it best to learn by example so follow this jupyter notebook to see the flow. 

